//FireMedia and SmokeMedia must be set to a boolean value

#declare Brown = color srgb < 87 / 255, 43 / 255, 7 / 255 >;

#macro GetGlobalScale( SingleFrameNumber, TotalFramesNumber )
	#local GlobalScale = 1;
	SetIfInsideInterval(0, 7, 0.5, 1, SingleFrameNumber, GlobalScale)
	SetIfInsideInterval(8, TotalFramesNumber - 8, 1, 1, SingleFrameNumber, GlobalScale)
	SetIfInsideInterval(TotalFramesNumber - 8, TotalFramesNumber, 1, 0.75, SingleFrameNumber, GlobalScale)
	GlobalScale
#end

#macro GetSmokeScatLimit( SingleFrameNumber, TotalFramesNumber )
	#local SmokeScatLimit = 0.95;
	#local DecreaseScatFrame = 12;//16 before
	SetIfInsideInterval(0, DecreaseScatFrame, 0.6, 0.6, SingleFrameNumber, SmokeScatLimit)
	SetIfInsideInterval(DecreaseScatFrame, TotalFramesNumber, 0.6, 0.45, SingleFrameNumber, SmokeScatLimit)
	SmokeScatLimit
#end

#macro MakeSmokePattern(SmokeScatLimit)
	bozo color_map{
			[0 color srgb 0 ]
			[0.2 color srgb 1 ]
			[SmokeScatLimit color srgb 1 ]
			[(SmokeScatLimit + 0.05) color srgb 0 ]
		}
		scale 0.25 warp{turbulence 0.25}
#end
	
#macro GetRedFire(SingleFrameNumber, TotalFramesNumber)
	#local RedFire = color srgb < 251 / 255, 103 / 255, 0 >;
	SetIfInsideInterval(16, TotalFramesNumber - 4, RedFire, 0, SingleFrameNumber, RedFire )
	#if( SingleFrameNumber >= TotalFramesNumber - 4 )
		#local RedFire = color srgb 0;
	#end
	RedFire
#end

#macro GetYellowFire(SingleFrameNumber, TotalFramesNumber)
	#local YellowFire = color srgb < 1, 243 / 255, 0 >;
	SetIfInsideInterval(16, TotalFramesNumber - 4, YellowFire, 0, SingleFrameNumber, YellowFire )
	#if( SingleFrameNumber >= TotalFramesNumber - 4 )
		#local YellowFire = color srgb 0;
	#end
	YellowFire
#end
	
#macro MakeFirePattern(	SingleFrameNumber, TotalFramesNumber, RedFire, YellowFire )			
	bozo color_map{
			[0 RedFire ]
			[0.6 RedFire ]
			[0.65 YellowFire ]
			[0.95 YellowFire ]
			[1.0 RedFire ]
		}
		translate -SingleFrameNumber / TotalFramesNumber * z	
		scale 0.25
#end

#macro MakeExplosionA_Sphere( SingleFrameNumber, TotalFramesNumber, SecondScale, PositionVector ) 
	#if( SingleFrameNumber >= TotalFramesNumber )
		#error concat("Error: bad 'SingleFrameNumber' value in 'MakeExplosionA_Sphere' macro.",
					" 'SingleFrameNumber' value is ", str( SingleFrameNumber ), " while max value should be : ",
					str( TotalFramesNumber - 1 ), " \n")
	#end
	sphere{ 0, 1 hollow no_shadow pigment{ color srgbft <0, 0, 0, 0, 1> }
		interior{
			#if( SmokeMedia )
				media{
					absorption 4 scattering{ 3, Brown } method 3 samples 1,30 intervals 1
					density{ spherical density_map{
									[0 color srgb 0 ]
									[0.1 MakeSmokePattern( GetSmokeScatLimit(SingleFrameNumber, TotalFramesNumber) ) ]
									[0.9 MakeSmokePattern( GetSmokeScatLimit(SingleFrameNumber, TotalFramesNumber) ) ]
							   }
					}
					rotate 360 / TotalFramesNumber * SingleFrameNumber * 0.25 * y
				}
			#end
			#if( FireMedia )
				media{
					emission 2 samples 1,30 intervals 10
					density{ spherical density_map{
									[0.1 color srgb 0 ]
									[0.15 MakeFirePattern(SingleFrameNumber, TotalFramesNumber, GetRedFire(SingleFrameNumber, TotalFramesNumber), GetYellowFire(SingleFrameNumber, TotalFramesNumber) ) ]
									[1 MakeFirePattern(SingleFrameNumber, TotalFramesNumber, GetRedFire(SingleFrameNumber, TotalFramesNumber), GetYellowFire(SingleFrameNumber, TotalFramesNumber) ) ]
								}
						warp{ turbulence 0.25 lambda 4 omega 0.6 }
					}
					rotate 360 / TotalFramesNumber * SingleFrameNumber * 0.5 * y
				}
			#end
		}
	scale GetGlobalScale( SingleFrameNumber, TotalFramesNumber )
	scale SecondScale
	translate PositionVector
	}
#end
